<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="obsolete">삭제</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="obsolete">전체 화면</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="obsolete">슬라이드 쇼</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="obsolete">내보내기</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="obsolete">복사</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="obsolete">즐겨찾기</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="obsolete">시계 방향으로 회전</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="obsolete">시계 반대 방향으로 회전</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="obsolete">배경화면으로 설정</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="obsolete">파일 관리자에 표시</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="obsolete">사진 정보</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="obsolete">복원</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>이름 미지정</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>생성</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>새 앨범</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>이 앨범을 삭제하시겠습니까?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>휴지통</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>즐겨찾기</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>가져오기</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>휴지통</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>즐겨찾기</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>또는 사진을 여기로 끌어다 놓기</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>모두 가져오기</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>가져오기 대상:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>가져오기</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>시스템 디스크</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>갤러리</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>디스크가 사용 중이므로, 지금 꺼낼 수 없습니다</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>확인</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>새 앨범</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>무시</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>앨범</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>바꾸기</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>내보내기</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>사진</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>문서</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>다운로드</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>바탕화면</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>동영상</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>음악</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>이름:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>저장 대상:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>형식:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>화질:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>다른 디렉터리 선택</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>확인</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>파일 이름은 비워 둘 수 없습니다</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>이미 존재합니다. 교체하시겠습니까?</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 드라이브</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>빈 %1 디스크</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 암호화됨</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1 볼륨</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>저장</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>사진 내보내기</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>삭제중...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>복원중...</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>기본 정보</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>세부 정보</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>가져오기</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>슬라이드 쇼</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>이름변경</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>내보내기</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>장치</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>갤러리</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>앨범</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>새 앨범</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>사진</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>전체 화면</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>파일 관리자에 표시</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>슬라이드 쇼</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>배경화면으로 설정</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>시계 방향으로 회전</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>시계 반대 방향으로 회전</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>이전</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>다음</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>즐겨찾기</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>즐겨찾기 해제</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>앨범 이름변경</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>앨범 &quot;%1&quot; 제거됨</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>&quot;%1&quot;에 성공적으로 추가되었습니다</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>가져오기 성공</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>가져오기 실패</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>내보내기 실패</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>내보내기 성공</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>모든 사진</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>타임라인</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>앨범</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>전체 화면/슬라이드쇼 종료</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>단축키 표시</translation>
    </message>
    <message>
        <source>View</source>
        <translation>보기</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>모두 선택</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>확대</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>축소</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>새 앨범</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>페이지 위로</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>페이지 아래로</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>가져오는 중...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">삭제</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>플래시</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>유형</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>File size</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>치수</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>캡처된 날짜</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>수정된 날짜</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>노출 모드</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>노출 프로그램</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>노출 시간</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>조리개</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>초점</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>최대 조리개</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>측광 모드</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>화이트 밸런스</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>플래시 보정</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>카메라 모델</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>렌즈 모델</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>컬러스페이스</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>태그</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>시스템 디스크</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>선택</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>선택 해제</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>가져온 위치</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>복원</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>사진</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>동영상</translation>
    </message>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>즐겨찾기</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>시계 반대 방향으로 회전</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>시계 방향으로 회전</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>가져오는 중...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Humans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>검색 결과 없음</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>슬라이드 쇼</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>검색 결과</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>보기</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>전체 화면</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>내보내기</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>즐겨찾기</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>즐겨찾기 해제</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>시계 방향으로 회전</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>시계 반대 방향으로 회전</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>파일 관리자에 표시</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>배경화면으로 설정</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>슬라이드 쇼</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>사진 정보</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>앨범에 추가</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>앨범에서 제거</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>복원</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>새 앨범</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>인쇄</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished">일간</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished">기본 정보</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation type="unfinished">수정된 날짜</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">유형</translation>
    </message>
    <message>
        <source>File size</source>
        <translation type="unfinished">File size</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished">캡처된 날짜</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
